@@ -189,6 +189,9 @@ class Journal:
     def filter(
         self,
         tags=[],
+        month=None,
+        day=None,
+        year=None,
         start_date=None,
         end_date=None,
         starred=False,
@@ -220,11 +223,19 @@ class Journal:
         if contains:
             contains_lower = contains.casefold()
 
+        # Create datetime object for comparison below
+        # this approach allows various formats
+        if month or day or year:
+            compare_d = time.parse(f"{month or 1}.{day or 1}.{year or 1}")
+
         result = [
             entry
             for entry in self.entries
             if (not tags or tagged(entry.tags))
             and (not starred or entry.starred)
+            and (not month or entry.date.month == compare_d.month)
+            and (not day or entry.date.day == compare_d.day)
+            and (not year or entry.date.year == compare_d.year)
             and (not start_date or entry.date >= start_date)
             and (not end_date or entry.date <= end_date)
             and (not exclude or not excluded(entry.tags))
