@@ -11,9 +11,11 @@ from .color import ERROR_COLOR
 from .color import RESET_COLOR
 from .config import get_journal_name
 from .config import scope_config
+from .config import get_config_path
 from .editor import get_text_from_editor
 from .editor import get_text_from_stdin
 from .exception import UserAbort
+from . import time
 
 
 def run(args):
@@ -76,6 +78,10 @@ def _is_write_mode(args, config, **kwargs):
             args.edit,
             args.export,
             args.end_date,
+            args.today_in_history,
+            args.month,
+            args.day,
+            args.year,
             args.limit,
             args.on_date,
             args.short,
@@ -205,8 +211,16 @@ def _search_journal(args, journal, **kwargs):
     if args.on_date:
         args.start_date = args.end_date = args.on_date
 
+    if args.today_in_history:
+        now = time.parse("now")
+        args.day = now.day
+        args.month = now.month
+
     journal.filter(
         tags=args.text,
+        month=args.month,
+        day=args.day,
+        year=args.year,
         start_date=args.start_date,
         end_date=args.end_date,
         strict=args.strict,
@@ -228,7 +242,7 @@ def _edit_search_results(config, journal, old_entries, **kwargs):
             f"""
             [{ERROR_COLOR}ERROR{RESET_COLOR}: There is no editor configured.]
 
-            Please specify an editor in config file ({install.CONFIG_FILE_PATH})
+            Please specify an editor in config file ({get_config_path()})
             to use the --edit option.
             """,
             file=sys.stderr,
